==> edjchain-1.0.3.tgz: package/exports/wallet.js <==
/**
 * Copyright 2018    . All Rights Reserved.
 *
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an 'AS IS' BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

const invoke = require("../interface/invoke");
const query = require("../interface/query");

exports.recordWallet = async function(walletId, walletName, organizationId) {
  try {
    const payload = {
      walletId,
      walletName,
      organizationId
    };
    await invoke(req.body.user, "recordWallet", payload);
    return "transaction submitted";
  } catch (err) {
    return err;
  }
};

exports.queryWallet = async function(walletId) {
  try {
    const queryJSON = {
      walletId
    };
    return await query(req.body.user, "queryWallet", queryJSON);
  } catch (err) {
    return err;
  }
};

exports.queryWalletHistory = async function() {
  // stub
};

exports.queryWalletList = async function() {
  try {
    const result = await query(req.body.user, "queryWalletList");
    res.status(200).send(result);
  } catch (err) {
    return err;
  }
};

exports.queryTransactionList = async function(r) {
  try {
    return await query(req.body.user, "queryTransactionList");
  } catch (err) {
    return err;
  }
};

exports.queryTransactionByType = async function(transactionType) {
  try {
    const queryJSON = {
      transactionType
    };
    return await query(req.body.user, "queryTransactionByType", queryJSON);
  } catch (err) {
    return err;
  }
};

exports.tokenTransfer = async function(
  transactionId,
  transactionType,
  amount,
  fromWalletId,
  toWalletId
) {
  try {
    const payload = {
      transactionId,
      transactionType,
      amount,
      fromWalletId,
      toWalletId
    };
    await invoke(req.body.user, "tokenTransfer", payload);
    return "transaction submitted";
  } catch (err) {
    return err;
  }
};

exports.tokenMint = async function(
  transactionId,
  transactionType,
  toWalletId,
  amount
) {
  try {
    const payload = {
      transactionId,
      transactionType,
      toWalletId,
      amount
    };
    await invoke(req.body.user, "tokenMint", payload);
    return "transaction submitted";
  } catch (err) {
    return err;
  }
};

exports.tokenBurn = async function(
  transactionId,
  transactionType,
  fromWalletId,
  amount
) {
  try {
    const payload = {
      transactionId,
      transactionType,
      fromWalletId,
      amount
    };
    await invoke(req.body.user, "tokenBurn", payload);
    return "transaction submitted";
  } catch (err) {
    return err;
  }
};

==> edjchain-1.0.12.tgz: package/exports/wallet.js <==
/**
 * Copyright 2018    . All Rights Reserved.
 *
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an 'AS IS' BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

const invoke = require("../interface/invoke");
const query = require("../interface/query");

exports.recordWallet = async function(
  user,
  walletId,
  walletName,
  organizationId
) {
  try {
    const payload = {
      walletId,
      walletName,
      organizationId
    };
    await invoke(user, "recordWallet", payload);
    return "transaction submitted";
  } catch (err) {
    return err;
  }
};

exports.queryWallet = async function(user, walletId) {
  try {
    const queryJSON = {
      walletId
    };
    return await query(user, "queryWallet", queryJSON);
  } catch (err) {
    return err;
  }
};

exports.queryWalletHistory = async function() {
  // stub
};

exports.queryWalletList = async function(user) {
  try {
    return await query(user, "queryWalletList");
  } catch (err) {
    return err;
  }
};

exports.queryTransactionList = async function(user) {
  try {
    return await query(user, "queryTransactionList");
  } catch (err) {
    return err;
  }
};

exports.queryTransactionByType = async function(user, transactionType) {
  try {
    const queryJSON = {
      transactionType
    };
    return await query(user, "queryTransactionByType", queryJSON);
  } catch (err) {
    return err;
  }
};

exports.tokenTransfer = async function(
  user,
  transactionId,
  transactionType,
  amount,
  fromWalletId,
  toWalletId
) {
  try {
    const payload = {
      transactionId,
      transactionType,
      amount,
      fromWalletId,
      toWalletId
    };
    await invoke(user, "tokenTransfer", payload);
    return "transaction submitted";
  } catch (err) {
    return err;
  }
};

exports.tokenMint = async function(
  user,
  transactionId,
  transactionType,
  toWalletId,
  amount
) {
  try {
    const payload = {
      transactionId,
      transactionType,
      toWalletId,
      amount
    };
    await invoke(user, "tokenMint", payload);
    return "transaction submitted";
  } catch (err) {
    return err;
  }
};

exports.tokenBurn = async function(
  user,
  transactionId,
  transactionType,
  fromWalletId,
  amount
) {
  try {
    const payload = {
      transactionId,
      transactionType,
      fromWalletId,
      amount
    };
    await invoke(user, "tokenBurn", payload);
    return "transaction submitted";
  } catch (err) {
    return err;
  }
};

exports.deleteWallet = async function(user, functionId) {
  try {
    const payload = {
      functionId
    };
    await invoke(user, "deleteWallet", payload);
    return "transaction submitted";
  } catch (err) {
    return err;
  }
};
